| Title: | Reactome Pathway Analysis |
|---|---|
| Description: | This package provides functions for pathway analysis based on REACTOME pathway database. It implements enrichment analysis, gene set enrichment analysis and several functions for visualization. This package is not affiliated with the Reactome team. |
| Authors: | Guangchuang Yu [aut, cre], Vladislav Petyuk [ctb] |
| Maintainer: | Guangchuang Yu <[email protected]> |
| License: | GPL-2 |
| Version: | 1.57.0 |
| Built: | 2026-05-30 09:37:23 UTC |
| Source: | https://github.com/bioc/ReactomePA |
Datasets sample contains a sample of gene IDs.
Pathway Enrichment Analysis of a gene set. Given a vector of genes, this function will return the enriched pathways with FDR control.
enrichPathway( gene, pvalueCutoff = 0.05, pAdjustMethod = "BH", universe = NULL, minGSSize = 10, maxGSSize = 500, qvalueCutoff = 0.2, organism = "human", readable = FALSE )enrichPathway( gene, pvalueCutoff = 0.05, pAdjustMethod = "BH", universe = NULL, minGSSize = 10, maxGSSize = 500, qvalueCutoff = 0.2, organism = "human", readable = FALSE )
gene |
a vector of entrez gene id. |
pvalueCutoff |
Cutoff value of pvalue. |
pAdjustMethod |
one of "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none" |
universe |
background genes |
minGSSize |
minimal size of genes annotated by Ontology term for testing. |
maxGSSize |
maximal size of each geneSet for analyzing |
qvalueCutoff |
Cutoff value of qvalue |
organism |
one of "human", "rat", "mouse", "celegans", "yeast", "zebrafish", "fly". |
readable |
whether mapping gene ID to gene Name |
A enrichResult instance.
Guangchuang Yu http://ygc.name
gene <- c("11171", "8243", "112464", "2194", "9318", "79026", "1654", "65003", "6240", "3476", "6238", "3836", "4176", "1017", "249") yy = enrichPathway(gene, pvalueCutoff=0.05) head(summary(yy)) #plot(yy)gene <- c("11171", "8243", "112464", "2194", "9318", "79026", "1654", "65003", "6240", "3476", "6238", "3836", "4176", "1017", "249") yy = enrichPathway(gene, pvalueCutoff=0.05) head(summary(yy)) #plot(yy)
get all entrezgene ID of a specific organism
getALLEG(organism)getALLEG(organism)
organism |
species |
entrez gene ID vector
Yu Guangchuang
mapping organism name to annotationDb package name
getDb(organism)getDb(organism)
organism |
one of supported organism |
annotationDb name
Yu Guangchuang
Gene Set Enrichment Analysis of Reactome Pathway
gsePathway( geneList, organism = "human", exponent = 1, minGSSize = 10, maxGSSize = 500, pvalueCutoff = 0.05, pAdjustMethod = "BH", verbose = TRUE, nPerm = 1000, method = "multilevel", adaptive = FALSE, minPerm = 101, maxPerm = 1e+05, pvalThreshold = 0.1 )gsePathway( geneList, organism = "human", exponent = 1, minGSSize = 10, maxGSSize = 500, pvalueCutoff = 0.05, pAdjustMethod = "BH", verbose = TRUE, nPerm = 1000, method = "multilevel", adaptive = FALSE, minPerm = 101, maxPerm = 1e+05, pvalThreshold = 0.1 )
geneList |
order ranked geneList |
organism |
organism |
exponent |
weight of each step |
minGSSize |
minimal size of each geneSet for analyzing |
maxGSSize |
maximal size of each geneSet for analyzing |
pvalueCutoff |
pvalue Cutoff |
pAdjustMethod |
pvalue adjustment method |
verbose |
print message or not |
nPerm |
The number of permutations for the "permute" method |
method |
one of "sample", "permute", "multilevel" |
adaptive |
logical |
minPerm |
minimal number of permutations for the "multilevel" method |
maxPerm |
maximal number of permutations for the "multilevel" method |
pvalThreshold |
The p-value threshold for the "multilevel" method |
gseaResult object
Yu Guangchuang
download the latest version of Reactome and stored in a 'GSON' object
gson_Reactome(organism = "human")gson_Reactome(organism = "human")
organism |
one of "human", "rat", "mouse", "celegans", "yeast", "zebrafish", "fly". |
a 'GSON' object
## Not run: rec_gson <- gson_Reactome("human") ## End(Not run)## Not run: rec_gson <- gson_Reactome("human") ## End(Not run)
view reactome pathway
viewPathway( pathName, organism = "human", readable = TRUE, foldChange = NULL, keyType = "ENTREZID", layout = "kk" )viewPathway( pathName, organism = "human", readable = TRUE, foldChange = NULL, keyType = "ENTREZID", layout = "kk" )
pathName |
pathway Name |
organism |
supported organism |
readable |
logical |
foldChange |
fold change |
keyType |
keyType of gene ID (i.e. names of foldChange, if available) |
layout |
graph layout |
plotting reactome pathway
plot
Yu Guangchuang